import numpy as np
import matplotlib.pyplot as plt
plt.style.use('ggplot')

from astropy.stats import LombScargle

rng = np.random.RandomState(42)

N = 100
t = 5 * rng.rand(N)
t -= 0.5 * (t % 1)  # create alias-inducing structure in the window function
dy = 0.5 * (1 + rng.rand(N))
y = dy * rng.randn(N)

ls = LombScargle(t, y, dy, normalization='standard')
z = np.linspace(1E-3, 0.15, 1000)

def false_alarm(method):
    return ls.false_alarm_probability(z, method=method, maximum_frequency=5)

fa_boot = ls.false_alarm_probability(z, method='bootstrap',
                                     maximum_frequency=5,
                                     method_kwds=dict(random_seed=42))

fig, ax = plt.subplots(figsize=(6, 4.5))

ax.plot(z, false_alarm('naive'), label='naive estimate')
ax.plot(z, false_alarm('baluev'), label='Baluev estimate')
ax.plot(z, false_alarm('davies'), ':k', label='Davies bound')
ax.plot(z, fa_boot, '-k', label='bootstrap estimate')

ax.legend(loc='lower left')
ax.set(yscale='log',
       title='False Alarm Estimates (N=100)',
       xlim=(0, 0.15), ylim=(0.01, 1.5),
       xlabel='Value of Highest Periodogram Peak',
       ylabel='False Alarm Probability');